### Replication Code for
### Sound the Alarm? Judicial Decisions Regarding PUblication and Dissent
### Morgan Hazelton, Rachael K. Hinkle, and Jee Seon Jeon
### American Politics Reserach 2016 (forthcoming)
### R version 3.2.3 (2015-12-20)

setwd("~/Dropbox/Appeals Court/HHJ_APR_Replication_Files/")
library(Zelig)
library(ZeligChoice)

data <- read.csv("HHJ.replication.data.csv")


### Table 1 
table(data$published, data$dissent)


### Table 2 

## Supreme Court Model
z.out.m1.sc <- zelig(list(mu1 = published ~ sc.M1.dist   +  caseload + criminal + status.quo.preserved + cir_maj_gop + amici + othCirCited, 
				mu2 = dissent ~ sc.M1.dist  + caseload  + criminal + status.quo.preserved  + cir_maj_gop + amici + othCirCited),
				data=data[data$s.case12a == 1, ], model="bprobit")		
summary(z.out.m1.sc)
# N
dim(data[data$s.case12a == 1 & !is.na(data$sc.M1.dist), ])

## En Banc Model	
z.out.m1.cir <- zelig(list(mu1 = published ~ cir.M1.dist  + caseload + criminal + status.quo.preserved + cir_maj_gop + amici + othCirCited,
				mu2 = dissent ~ cir.M1.dist +  caseload  + criminal + status.quo.preserved + cir_maj_gop + amici + othCirCited),
				data=data[data$cir.case12a == 1, ], model="bprobit")
summary(z.out.m1.cir)
dim(data[data$cir.case12a == 1 & !is.na(data$cir.M1.dist), ])


### Figure 4
adata <- data[data$s.case12 == 1 & !is.na(data$s.case12), ]
cdata <- data[data$cir.case12 == 1 & !is.na(data$cir.case12), ]

x.out.m1.sc <- setx(z.out.m1.sc, sc.M1.dist = median(adata$sc.M1.dist), caseload = median(adata$caseload), criminal = median(adata$criminal), status.quo.preserved = median(adata$status.quo.preserved), cir_maj_gop = median(adata$cir_maj_gop), amici = median(adata$amici), othCirCited = median(adata$othCirCited),  data=adata)
s.out.m1.sc <- sim(z.out.m1.sc, x=x.out.m1.sc)	

x.out.m1.cir <- setx(z.out.m1.cir, cir.M1.dist = median(cdata$cir.M1.dist), caseload = median(adata$caseload), criminal = median(adata$criminal), status.quo.preserved = median(adata$status.quo.preserved), cir_maj_gop = median(adata$cir_maj_gop), amici = median(adata$amici), othCirCited = median(adata$othCirCited), data=cdata)
s.out.m1.cir <- sim(z.out.m1.cir, x=x.out.m1.cir)	

msrul <- seq(from=min(adata$sc.M1.dist, na.rm=T), to=max(adata$sc.M1.dist, na.rm=T), by=.001)
length(msrul)
cmsrul <- seq(from=min(adata$cir.M1.dist, na.rm=T), to=max(adata$cir.M1.dist, na.rm=T), by=.001)
length(cmsrul)

x.out.msrul.sc <- setx(z.out.m1.sc, sc.M1.dist = msrul, caseload = median(adata$caseload), criminal = median(adata$criminal), status.quo.preserved = median(adata$status.quo.preserved), cir_maj_gop = median(adata$cir_maj_gop), amici = median(adata$amici), othCirCited = median(adata$othCirCited), data=adata)
s.out.msrul.sc <- sim(z.out.m1.sc, x=x.out.msrul.sc, num=1000)

x.out.msrul.cir <- setx(z.out.m1.cir, cir.M1.dist = cmsrul, caseload = median(adata$caseload), criminal = median(adata$criminal), status.quo.preserved = median(adata$status.quo.preserved), cir_maj_gop = median(adata$cir_maj_gop), amici = median(adata$amici), othCirCited = median(adata$othCirCited), data=cdata)
s.out.msrul.cir <- sim(z.out.m1.cir, x=x.out.msrul.cir, num=1000)

mslines.sc <- as.data.frame(cbind(rep(NA, length(msrul)), rep(NA, length(msrul)), rep(NA, length(msrul)), rep(NA, length(msrul))))
for(i in 1:length(msrul)){
	mslines.sc$msrul[i] <- msrul[i]
	mslines.sc$med[i] <- s.out.msrul.sc[[i]]$stats[[1]][1,3]
	mslines.sc$lci[i] <- s.out.msrul.sc[[i]]$stats[[1]][1,4]
	mslines.sc$uci[i] <- s.out.msrul.sc[[i]]$stats[[1]][1,5]
	mslines.sc$dmed[i] <- s.out.msrul.sc[[i]]$stats[[1]][2,3]
	mslines.sc$dlci[i] <- s.out.msrul.sc[[i]]$stats[[1]][2,4]
	mslines.sc$duci[i] <- s.out.msrul.sc[[i]]$stats[[1]][2,5]
	mslines.sc$pmed[i] <- s.out.msrul.sc[[i]]$stats[[1]][3,3]
	mslines.sc$plci[i] <- s.out.msrul.sc[[i]]$stats[[1]][3,4]
	mslines.sc$puci[i] <- s.out.msrul.sc[[i]]$stats[[1]][3,5]
	mslines.sc$pdmed[i] <- s.out.msrul.sc[[i]]$stats[[1]][4,3]
	mslines.sc$pdlci[i] <- s.out.msrul.sc[[i]]$stats[[1]][4,4]
	mslines.sc$pduci[i] <- s.out.msrul.sc[[i]]$stats[[1]][4,5]
}

mslines.cir <- as.data.frame(cbind(rep(NA, length(cmsrul)), rep(NA, length(cmsrul)), rep(NA, length(cmsrul)), rep(NA, length(cmsrul))))
for(i in 1:length(cmsrul)){
	mslines.cir$msrul[i] <- cmsrul[i]
	mslines.cir$med[i] <- s.out.msrul.cir[[i]]$stats[[1]][1,3]
	mslines.cir$lci[i] <- s.out.msrul.cir[[i]]$stats[[1]][1,4]
	mslines.cir$uci[i] <- s.out.msrul.cir[[i]]$stats[[1]][1,5]
	mslines.cir$dmed[i] <- s.out.msrul.cir[[i]]$stats[[1]][2,3]
	mslines.cir$dlci[i] <- s.out.msrul.cir[[i]]$stats[[1]][2,4]
	mslines.cir$duci[i] <- s.out.msrul.cir[[i]]$stats[[1]][2,5]
	mslines.cir$pmed[i] <- s.out.msrul.cir[[i]]$stats[[1]][3,3]
	mslines.cir$plci[i] <- s.out.msrul.cir[[i]]$stats[[1]][3,4]
	mslines.cir$puci[i] <- s.out.msrul.cir[[i]]$stats[[1]][3,5]
	mslines.cir$pdmed[i] <- s.out.msrul.cir[[i]]$stats[[1]][4,3]
	mslines.cir$pdlci[i] <- s.out.msrul.cir[[i]]$stats[[1]][4,4]
	mslines.cir$pduci[i] <- s.out.msrul.cir[[i]]$stats[[1]][4,5]
}

par(mfrow=c(2,2))
plot(c(min(msrul), max(msrul)), c(0,1), type="n", xlab="|M - s|", ylab="Predicted Probability of Publication", main="Supreme Court", axes=T)
polygon(c(mslines.sc$msrul,rev(mslines.sc$msrul)), c(mslines.sc$puci+mslines.sc$pduci,rev(mslines.sc$plci+mslines.sc$pdlci)), col="lightgrey", border=NA)#, density=30)
lines(mslines.sc$msrul, mslines.sc$pmed + mslines.sc$pdmed, type="l", lwd=2, lty=2, col="black")

plot(c(min(cmsrul), max(cmsrul)), c(0,1), type="n", xlab="|M - s|", ylab="Predicted Probability of Publication", main="En Banc", axes=T)
polygon(c(mslines.cir$msrul,rev(mslines.cir$msrul)), c(mslines.cir$puci+mslines.cir$pduci,rev(mslines.cir$plci+mslines.cir$pdlci)), col="lightgrey", border=NA)#, density=30)
lines(mslines.cir$msrul, mslines.cir$pmed + mslines.cir$pdmed, type="l", lwd=2, lty=1, col="black")

plot(c(min(msrul), max(msrul)), c(0,.15), type="n", xlab="|M - s|", ylab="Predicted Probability of Dissent", main="Supreme Court", axes=T)
polygon(c(mslines.sc$msrul,rev(mslines.sc$msrul)), c((mslines.sc$duci+mslines.sc$pduci),rev((mslines.sc$dlci+mslines.sc$pdlci))), col="lightgrey", border=NA)
lines(mslines.sc$msrul, mslines.sc$pdmed+mslines.sc$dmed, type="l", lwd=2, lty=1, col="black")

plot(c(min(cmsrul), max(cmsrul)), c(0,.15), type="n", xlab="|M - s|", ylab="Predicted Probability of Dissent", main="En Banc", axes=T)
polygon(c(mslines.cir$msrul,rev(mslines.cir$msrul)), c((mslines.cir$duci+mslines.cir$pduci),rev((mslines.cir$dlci+mslines.cir$pdlci))), col="lightgrey", border=NA)
lines(mslines.cir$msrul, mslines.cir$pdmed+mslines.cir$dmed, type="l", lwd=2, lty=2, col="black")


### Appendix A

## Publication
table(data$published, data$EB.granted)
table(data$published, data$Cert.Granted)
(7/(7+2165))*100  
(29/(29+1562))*100  

## Dissent
table(data$dissent, data$EB.granted)
(7/(7+3486))*100 
(7/(7+263))*100
table(data$dissent, data$Cert.Granted)
(30/(30+3463))*100  
(6/(6+264))*100  


### Appendix C

## Percentage of dissents authored by m

# m0: defined using party: m is R on RDD panel and D on RRD panel
table(data$m0 == data$dissenter.jcs)
(98/(98+104))*100
# m1: defined using our method (see p.)
table(data$m1 == data$dissenter.jcs)
(120/(120+142))*100
# m2: defined as located farthest from panel median
table(data$m2 == data$dissenter.jcs)
(109/(109+161))*100
# m3s: defined as located farthest from Supreme Court median
table(data$m3s == data$dissenter.jcs)
(119/(119+151))*100
# m3s: defined as located farthest from full circuit median
table(data$m3c == data$dissenter.jcs)
(113/(113+157))*100

# m1: defined using our method (see p.), limited to cases analyzed
table(data$m1[data$s.case12a == 1] == data$dissenter.jcs[data$s.case12a == 1])
(83/(83+88))*100
table(data$m1[data$cir.case12a == 1] == data$dissenter.jcs[data$cir.case12a == 1])
(89/(89+101))*100


### Appendix D

## Supreme Court Model
z.out.m1.scD <- zelig(list(mu1 = published ~ sc.M1.dist   +  caseload + criminal + status.quo.preserved + cir_maj_gop + amici + othCirCited, 
				mu2 = m1dissent ~ sc.M1.dist  + caseload  + criminal + status.quo.preserved  + cir_maj_gop + amici + othCirCited),
				data=data[data$s.case12a == 1, ], model="bprobit")		
summary(z.out.m1.scD)
# N
dim(data[data$s.case12a == 1 & !is.na(data$sc.M1.dist), ])

## En Banc Model	
z.out.m1.cirD <- zelig(list(mu1 = published ~ cir.M1.dist  + caseload + criminal + status.quo.preserved + cir_maj_gop + amici + othCirCited,
				mu2 = m1dissent ~ cir.M1.dist +  caseload  + criminal + status.quo.preserved + cir_maj_gop + amici + othCirCited),
				data=data[data$cir.case12a == 1, ], model="bprobit")
summary(z.out.m1.cirD)
dim(data[data$cir.case12a == 1 & !is.na(data$cir.M1.dist), ])

